@@ -4,8 +4,8 @@ import click
 
 @click.command()
 @click.option(
-    '--submission-dir', '-sd', required=True,
-    help='Submission directory.'
+    '--input-dir', '-i', required=True,
+    help='Input directory.'
 )
 @click.option(
     '--output-dir', '-o', 
@@ -32,15 +32,13 @@ import click
     '--hash-operator', '-ho', type=click.FloatRange(0,1),
     help='Use hash operator metric and set up hash operator threshold.'
 )
-def scoss_command(submission_dir, output_dir, threshold_combination,\
+def scoss_command(input_dir, output_dir, threshold_combination,\
     moss, count_operator, set_operator, hash_operator):
     if not output_dir:
         output_dir = './'
 
-    scoss.get_all_plagiarism(submission_dir, output_dir, threshold_combination, 
+    scoss.get_all_plagiarism(input_dir, output_dir, threshold_combination, 
         moss, count_operator, set_operator, hash_operator)
 
 if __name__ == '__main__':
-    # python scoss_cli.py -sd tests/data/299721 -tc OR -co 0.1 -ho 0.1 -mo 0.1 -o tests/data
-    # python scoss_cli.py -sd tests/data/299721 -tc OR -co 0.9 -ho 0.7 -o tests/data
     scoss_command()
\ No newline at end of file
