@@ -25,7 +25,7 @@ class MySource(Source):
             return the Source object
             :rtype: Source
         """
-        with open(filepath) as f:
+        with open(filepath, encoding='utf-8') as f:
             source_str = f.read()
         if lang is None:
             ext = os.path.splitext(filepath)[1][1:]
